@@ -267,27 +267,22 @@ static void *config_server_create(pool *p, server_rec *s)
 /*
  *  Merge per-server SSL configurations
  */
-#define Merge(el,unset)  new->el = add->el == unset ? base->el : add->el
-#define MergeString(el)  Merge(el,NULL)
-#define MergeBool(el)    Merge(el,UNSET)
-#define MergeInt(el)     Merge(el,0)
-
 static void *config_server_merge(pool *p, void *basev, void *addv)
 {
     SSLConfigRec *base = (SSLConfigRec *)basev;
     SSLConfigRec *add  = (SSLConfigRec *)addv;
     SSLConfigRec *new  = (SSLConfigRec *)ap_pcalloc(p, sizeof(SSLConfigRec));
 
-    MergeBool(bDisabled);
-    MergeString(szCertificateFile);
-    MergeString(szKeyFile);
-    MergeString(szCACertificatePath);
-    MergeString(szCACertificateFile);
-    MergeString(szLogFile);
-    MergeInt(nVerifyDepth);
-    Merge(nVerifyClient, VERIFY_UNSET);
-    MergeBool(bFakeBasicAuth);
-    MergeInt(tSessionCacheTimeout);
+    cfgMergeBool(bDisabled);
+    cfgMergeString(szCertificateFile);
+    cfgMergeString(szKeyFile);
+    cfgMergeString(szCACertificatePath);
+    cfgMergeString(szCACertificateFile);
+    cfgMergeString(szLogFile);
+    cfgMergeInt(nVerifyDepth);
+    cfgMerge(nVerifyClient, VERIFY_UNSET);
+    cfgMergeBool(bFakeBasicAuth);
+    cfgMergeInt(tSessionCacheTimeout);
 
     return new;
 }
@@ -316,11 +311,9 @@ static void *config_perdir_merge(pool *p, void *basev, void *addv)
     SSLDirConfigRec *new  = (SSLDirConfigRec *)ap_palloc(p, 
                                                sizeof(SSLDirConfigRec));
 
-    new->tbRequiredCiphers = ap_overlay_tables(p, add->tbRequiredCiphers,
-                                                  base->tbRequiredCiphers);
-    new->tbBannedCiphers   = ap_overlay_tables(p, add->tbBannedCiphers,
-                                                  base->tbBannedCiphers);
-    new->bSSLRequired      = base->bSSLRequired || add->bSSLRequired;
+	cfgMergeTable(tbRequiredCiphers);
+	cfgMergeTable(tbBannedCiphers);
+	cfgMerge(bSSLRequired, FALSE);
 
     return new;
 }
@@ -332,7 +325,7 @@ static void *config_perdir_merge(pool *p, void *basev, void *addv)
 static const char *cmd_PolySetSlotString(
     cmd_parms *cmd, char *struct_ptr, char *arg)
 {
-    char *pConfig = ap_get_module_config(cmd->server->module_config, &ssl_module);
+    char *pConfig = (char *)mySrvConfig(cmd->server);
 
     int offset = (int)cmd->info;
     *(char **)(pConfig + offset) = arg;
@@ -342,7 +335,7 @@ static const char *cmd_PolySetSlotString(
 static const char *cmd_PolySetSlotInt(
     cmd_parms *cmd, char *struct_ptr, char *arg)
 {
-    char *pConfig = ap_get_module_config(cmd->server->module_config, &ssl_module);
+    char *pConfig = (char *)mySrvConfig(cmd->server);
 
     int offset = (int)cmd->info;
     *(int *)(pConfig + offset) = atoi(arg);
@@ -352,7 +345,7 @@ static const char *cmd_PolySetSlotInt(
 static const char *cmd_PolySetSlotTrue(
     cmd_parms *cmd, char *struct_ptr)
 {
-    char *pConfig = ap_get_module_config(cmd->server->module_config, &ssl_module);
+    char *pConfig = (char *)mySrvConfig(cmd->server);
 
     int offset = (int)cmd->info;
     *(BOOL *)(pConfig + offset) = TRUE;
@@ -362,7 +355,7 @@ static const char *cmd_PolySetSlotTrue(
 static const char *cmd_PolySetSlotFalse(
     cmd_parms *cmd, char *struct_ptr)
 {
-    char *pConfig = ap_get_module_config(cmd->server->module_config, &ssl_module);
+    char *pConfig = (char *)mySrvConfig(cmd->server);
 
     int offset = (int)cmd->info;
     *(BOOL *)(pConfig + offset) = FALSE;
@@ -415,15 +408,15 @@ static const char *cmd_SSLCacheServerPath(
 static const char *cmd_SSLVerifyClient(
     cmd_parms *cmd, char *struct_ptr, char *level)
 {
-    SSLConfigRec *pConfig = 
-        ap_get_module_config(cmd->server->module_config, &ssl_module);
-    if (strcmp(level, "0") == 0 || strcasecmp(level, "none") == 0)
+    SSLConfigRec *pConfig = mySrvConfig(cmd->server);
+
+    if (strEQ(level, "0") || strcEQ(level, "none"))
         pConfig->nVerifyClient = VERIFY_NONE;
-    else if (strcmp(level, "1") == 0 || strcasecmp(level, "optional") == 0)
+    else if (strEQ(level, "1") || strcEQ(level, "optional"))
         pConfig->nVerifyClient = VERIFY_OPTIONAL;
-    else if (strcmp(level, "2") == 0 || strcasecmp(level, "require") == 0)
+    else if (strEQ(level, "2") || strcEQ(level, "require"))
         pConfig->nVerifyClient = VERIFY_REQUIRE;
-    else if (strcmp(level, "3") == 0 || strcasecmp(level, "optional_no_ca") == 0)
+    else if (strEQ(level, "3") || strcEQ(level, "optional_no_ca"))
         pConfig->nVerifyClient = VERIFY_OPTIONAL_NO_CA;
     else
         return "SSLVerifyClient: Invalid argument";
@@ -543,7 +536,7 @@ static void init_Module(server_rec *s, pool *p)
     }
     if (!g_szCacheServerPath) {
         ap_log_error(APLOG_MARK, APLOG_ERR, s,
-                     "mod_ssl: Required SSLCacheServerPath missing\n");
+                     "mod_ssl: Required SSLCacheServerPath missing");
         ap_clear_pool(p);
         exit(1);
     }
@@ -562,8 +555,7 @@ static void init_Module(server_rec *s, pool *p)
      *  initialize servers
      */
     for (; s != NULL; s = s->next) {
-        SSLConfigRec *pConfig = 
-            ap_get_module_config(s->module_config, &ssl_module);
+        SSLConfigRec *pConfig = mySrvConfig(s);
 
         /* Fix up stuff that may not have been set */
         if (pConfig->bDisabled == UNSET)
@@ -657,9 +649,9 @@ static void init_Module(server_rec *s, pool *p)
     cp = __SSLeay SSLeay_version(SSLEAY_VERSION);
     for (; !isdigit(*cp); cp++);
     strcpy(buf, "SSLeay/");
-    for (cp2 = buf + strlen(buf); *cp != ' ' && *cp != '\0';)
+    for (cp2 = buf + strlen(buf); *cp != ' ' && *cp != NUL;)
         *cp2++ = *cp++;
-    *cp2 = '\0';
+    *cp2 = NUL;
     ap_add_version_component(ap_pstrdup(p, buf));
 
     return;
@@ -858,8 +850,7 @@ static int init_VerifyFlags(SSLConfigRec *pConfig)
 {
     server_rec *srvr = conn->server;
     BUFF *fb = conn->client;
-    SSLConfigRec *pConfig = 
-        ap_get_module_config(srvr->module_config, &ssl_module);
+    SSLConfigRec *pConfig = mySrvConfig(srvr);
 
     /*
      * Immediately stop processing if SSL is disabled for
@@ -972,8 +963,7 @@ static void SSL_HOOK_CloseConnection(void *_ssl)
  */
 static int ssl_hook_Auth(request_rec *r)
 {
-    SSLConfigRec *pConfig = ap_get_module_config(r->server->module_config,
-                                                 &ssl_module);
+    SSLConfigRec *pConfig = mySrvConfig(r->server);
     char b1[MAX_STRING_LEN], b2[MAX_STRING_LEN];
 
     /*
@@ -1014,10 +1004,8 @@ static int ssl_hook_Auth(request_rec *r)
 static int ssl_hook_Access(request_rec *r)
 {
     char *cipher;
-    SSLDirConfigRec *rec = 
-        (SSLDirConfigRec *)ap_get_module_config(r->per_dir_config, &ssl_module);
-    SSLConfigRec *pConfig = 
-        (SSLConfigRec *)ap_get_module_config(r->server->module_config, &ssl_module);
+    SSLDirConfigRec *rec  = myDirConfig(r);
+    SSLConfigRec *pConfig = mySrvConfig(r->server);
 
     /*
      * Support for SSLRequire directive
@@ -1074,8 +1062,7 @@ static int ssl_hook_Fixup(request_rec *r)
     int n;
     X509 *xs;
 
-    SSLConfigRec *pConfig = 
-        (SSLConfigRec *)ap_get_module_config(r->server->module_config, &ssl_module);
+    SSLConfigRec *pConfig = mySrvConfig(r->server);
 
     /* 
      * Check to see if SSL is on
@@ -1100,7 +1087,7 @@ static int ssl_hook_Fixup(request_rec *r)
                  __SSLeay SSLeay_version(SSLEAY_VERSION));
 
     for (n = 0; aCipherspecs[n].szName; ++n) {
-        if (!strcmp(cipher, aCipherspecs[n].szName)) {
+        if (strEQ(cipher, aCipherspecs[n].szName)) {
             keysize = aCipherspecs[n].nKeySize;
             secretkeysize = aCipherspecs[n].nSecretKeySize;
             break;
@@ -1158,8 +1145,7 @@ static int ssl_callback_SSLVerify(int ok, X509_STORE_CTX *ctx)
     int depth = __SSLeay X509_STORE_CTX_get_error_depth(ctx);
     int error = __SSLeay X509_STORE_CTX_get_error(ctx);
 
-    SSLConfigRec *pConfig = 
-        ap_get_module_config(g_pCurrentConnection->server->module_config, &ssl_module);
+    SSLConfigRec *pConfig = mySrvConfig(g_pCurrentConnection->server);
 
 #if DEBUG_VERIFY
     {
@@ -1267,7 +1253,7 @@ static void ssl_int_ExpandCert(table *pEnv, char *szPrefix, char *szCert)
     strcpy(buf, szCert);
     for (s = strtok(buf, "/"); s != NULL; s = strtok(NULL, "/")) {
         int n = strcspn(s, "=");
-        s[n] = '\0';
+        s[n] = NUL;
         util_strupper(s);
         ap_snprintf(var, sizeof(var), "%s%s", szPrefix, s);
         ap_table_set(pEnv, var, s + n + 1);
@@ -1276,8 +1262,7 @@ static void ssl_int_ExpandCert(table *pEnv, char *szPrefix, char *szCert)
 
 static void ssl_int_SetupVerify(conn_rec *conn)
 {
-    SSLConfigRec *pConfig = ap_get_module_config(conn->server->module_config,
-                                                 &ssl_module);
+    SSLConfigRec *pConfig = mySrvConfig(conn->server);
 
     conn->client->szClientX509 = NULL;
 
@@ -1299,8 +1284,7 @@ static void ssl_int_SetupVerify(conn_rec *conn)
 
 static BOOL ssl_int_SetCertStuff(conn_rec *conn)
 {
-    SSLConfigRec *pConfig = ap_get_module_config(conn->server->module_config,
-                                                 &ssl_module);
+    SSLConfigRec *pConfig = mySrvConfig(conn->server);
     SSL *con = conn->client->ssl;
     char *cert_file = pConfig->szCertificateFile;
 
@@ -1363,8 +1347,7 @@ static void SendSessionToServer(SSL_SESSION *pSession)
     SSLConfigRec *pConfig;
     time_t tExpiresAt;
 
-    pConfig = 
-        ap_get_module_config(g_pCurrentConnection->server->module_config, &ssl_module);
+    pConfig = mySrvConfig(g_pCurrentConnection->server);
 
     if (LocalCacheFind(pSession->session_id, pSession->session_id_length))
         return;
@@ -1500,7 +1483,7 @@ static void util_uuencode(char *szTo, const char *szFrom)
         if (!s[2])
             break;
     }
-    *szTo++ = '\0';
+    *szTo++ = NUL;
     return;
 }
 
